spec = {
    "name": "FAO",
    "title": (
        "Food and Agriculture Organization of the United Nations (FAO) "
        "FAOSTAT data set categorisation"
    ),
    "comment": "Needed to add FAOSTAT data to PRIMAP-hist",
    "references": "",
    "institution": "FAO",
    "hierarchical": True,
    "last_update": "2024-12-10",
    "version": "2024",
    "total_sum": True,
    "canonical_top_level_category": "0",
    "categories": {
        "0": {
            "title": "Total",
            "comment": "All emissions and removals",
            "children": [["1", "2", "3"]],
        },
        "1": {
            "title": "Crops",
            "comment": "Crops",
            "alternative_codes": "1",
            "children": [["1.A", "1.B"]],
            "info": {"gases": ["CH4", "N2O"]},
        },
        "2": {
            "title": "Energy use in agriculture",
            "comment": "Energy use in agriculture",
            "alternative_codes": "2",
            "children": [["2.A", "2.B", "2.C", "2.D", "2.E"]],
            "info": {"gases": ["CH4", "N2O", "CO2"]},
        },
        "3": {
            "title": "Livestock",
            "comment": "Livestock",
            "alternative_codes": "3",
            "children": [
                [
                    "3.A",
                    "3.B",
                    "3.C",
                    "3.D",
                    "3.E",
                    "3.F",
                    "3.G",
                    "3.H",
                    "3.I",
                    "3.J",
                    "3.K",
                    "3.L",
                    "3.M",
                    "3.N",
                    "3.O",
                    "3.P",
                    "3.Q",
                    "3.R",
                ]
            ],
            "info": {"gases": ["CH4", "N2O"]},
        },
        "1.A": {
            "title": "All crops",
            "comment": "All crops",
            "alternative_codes": "1A",
            "children": [
                [
                    "1.A.1",
                    "1.A.2",
                    "1.A.3",
                    "1.A.4",
                    "1.A.5",
                    "1.A.6",
                    "1.A.7",
                    "1.A.8",
                    "1.A.9",
                    "1.A.10",
                    "1.A.11",
                    "1.A.12",
                ]
            ],
            "info": {"gases": ["CH4", "N2O"]},
        },
        "1.A.1": {
            "title": "Wheat",
            "comment": "Wheat",
            "alternative_codes": ["1A1"],
            "info": {"gases": ["CH4", "N2O"]},
            "children": [["1.A.1.a", "1.A.1.b"]],
        },
        "1.A.1.a.i": {
            "title": "Wheat crop residues direct emissions",
            "comment": "Wheat crop residues direct emissions",
            "alternative_codes": ["1A1a"],
            "info": {"gases": ["N2O"]},
        },
        "1.A.1.a.ii": {
            "title": "Wheat crop residues indirect emissions",
            "comment": "Wheat crop residues indirect emissions",
            "alternative_codes": ["1A1ai"],
            "info": {"gases": ["N2O"]},
        },
        "1.A.1.a": {
            "title": "Wheat crop residues",
            "comment": "Wheat crop residues",
            "alternative_codes": ["1A1a"],
            "info": {"gases": ["N2O"]},
            "children": [["1.A.1.a.ii", "1.A.1.a.i"]],
        },
        "1.A.1.b": {
            "title": "Wheat burning crop residues",
            "comment": "Wheat burning crop residues",
            "alternative_codes": ["1A1b"],
            "info": {"gases": ["CH4", "N2O"]},
        },
        "1.A.2": {
            "title": "Rice",
            "comment": "Rice",
            "alternative_codes": ["1A2"],
            "info": {"gases": ["CH4", "N2O"]},
            "children": [["1.A.2.a", "1.A.2.b", "1.A.2.c"]],
        },
        "1.A.2.a.i": {
            "title": "Rice crop residues direct emissions",
            "comment": "Rice crop residues direct emissions",
            "alternative_codes": ["1A2a"],
            "info": {"gases": ["N2O"]},
        },
        "1.A.2.a.ii": {
            "title": "Rice crop residues indirect emissions",
            "comment": "Rice crop residues indirect emissions",
            "alternative_codes": ["1A2ai"],
            "info": {"gases": ["N2O"]},
        },
        "1.A.2.a": {
            "title": "Rice crop residues",
            "comment": "Rice crop residues",
            "alternative_codes": ["1A2a"],
            "info": {"gases": ["N2O"]},
            "children": [["1.A.2.a.ii", "1.A.2.a.i"]],
        },
        "1.A.2.b": {
            "title": "Rice burning crop residues",
            "comment": "Rice burning crop residues",
            "alternative_codes": ["1A2b"],
            "info": {"gases": ["CH4", "N2O"]},
        },
        "1.A.2.c": {
            "title": "Rice cultivation",
            "comment": "Rice cultivation",
            "alternative_codes": ["1A2c"],
            "info": {"gases": ["CH4"]},
        },
        "1.A.3": {
            "title": "Potatoes",
            "comment": "Potatoes",
            "alternative_codes": ["1A3"],
            "info": {"gases": "N2O"},
            "children": [["1.A.3.a"]],
        },
        "1.A.3.a.i": {
            "title": "Potatoes crop residues direct emissions",
            "comment": "Potatoes crop residues direct emissions",
            "alternative_codes": ["1A3a"],
            "info": {"gases": ["N2O"]},
        },
        "1.A.3.a.ii": {
            "title": "Potatoes crop residues indirect emissions",
            "comment": "Potatoes crop residues indirect emissions",
            "alternative_codes": ["1A3ai"],
            "info": {"gases": ["N2O"]},
        },
        "1.A.3.a": {
            "title": "Potatoes crop residues",
            "comment": "Potatoes crop residues",
            "alternative_codes": ["1A3a"],
            "info": {"gases": ["N2O"]},
            "children": [["1.A.3.a.ii", "1.A.3.a.i"]],
        },
        "1.A.4": {
            "title": "Millet",
            "comment": "Millet",
            "alternative_codes": ["1A4"],
            "info": {"gases": "N2O"},
            "children": [["1.A.4.a"]],
        },
        "1.A.4.a.i": {
            "title": "Millet crop residues direct emissions",
            "comment": "Millet crop residues direct emissions",
            "alternative_codes": ["1A4a"],
            "info": {"gases": ["N2O"]},
        },
        "1.A.4.a.ii": {
            "title": "Millet crop residues indirect emissions",
            "comment": "Millet crop residues indirect emissions",
            "alternative_codes": ["1A4ai"],
            "info": {"gases": ["N2O"]},
        },
        "1.A.4.a": {
            "title": "Millet crop residues",
            "comment": "Millet crop residues",
            "alternative_codes": ["1A4a"],
            "info": {"gases": ["N2O"]},
            "children": [["1.A.4.a.ii", "1.A.4.a.i"]],
        },
        "1.A.5": {
            "title": "Barley",
            "comment": "Barley",
            "alternative_codes": ["1A5"],
            "info": {"gases": "N2O"},
            "children": [["1.A.5.a"]],
        },
        "1.A.5.a.i": {
            "title": "Barley crop residues direct emissions",
            "comment": "Barley crop residues direct emissions",
            "alternative_codes": ["1A5a"],
            "info": {"gases": ["N2O"]},
        },
        "1.A.5.a.ii": {
            "title": "Barley crop residues indirect emissions",
            "comment": "Barley crop residues indirect emissions",
            "alternative_codes": ["1A5ai"],
            "info": {"gases": ["N2O"]},
        },
        "1.A.5.a": {
            "title": "Barley crop residues",
            "comment": "Barley crop residues",
            "alternative_codes": ["1A5a"],
            "info": {"gases": ["N2O"]},
            "children": [["1.A.5.a.ii", "1.A.5.a.i"]],
        },
        "1.A.6": {
            "title": "Maize (corn)",
            "comment": "Maize (corn)",
            "alternative_codes": ["1A6"],
            "info": {"gases": ["CH4", "N2O"]},
            "children": [["1.A.6.a", "1.A.6.b"]],
        },
        "1.A.6.a.i": {
            "title": "Maize (corn) crop residues direct emissions",
            "comment": "Maize (corn) crop residues direct emissions",
            "alternative_codes": ["1A6a"],
            "info": {"gases": ["N2O"]},
        },
        "1.A.6.a.ii": {
            "title": "Maize (corn) crop residues indirect emissions",
            "comment": "Maize (corn) crop residues indirect emissions",
            "alternative_codes": ["1A6ai"],
            "info": {"gases": ["N2O"]},
        },
        "1.A.6.a": {
            "title": "Maize (corn) crop residues",
            "comment": "Maize (corn) crop residues",
            "alternative_codes": ["1A6a"],
            "info": {"gases": ["N2O"]},
            "children": [["1.A.6.a.ii", "1.A.6.a.i"]],
        },
        "1.A.6.b": {
            "title": "Maize (corn) burning crop residues",
            "comment": "Maize (corn) burning crop residues",
            "alternative_codes": ["1A6b"],
            "info": {"gases": ["CH4", "N2O"]},
        },
        "1.A.7": {
            "title": "Sugar cane",
            "comment": "Sugar cane",
            "alternative_codes": ["1A7"],
            "info": {"gases": ["CH4", "N2O"]},
            "children": [["1.A.7.a", "1.A.7.b"]],
        },
        "1.A.7.a.i": {
            "title": "Sugar cane crop residues direct emissions",
            "comment": "Sugar cane crop residues direct emissions",
            "alternative_codes": ["1A7a"],
            "info": {"gases": ["N2O"]},
        },
        "1.A.7.a.ii": {
            "title": "Sugar cane crop residues indirect emissions",
            "comment": "Sugar cane crop residues indirect emissions",
            "alternative_codes": ["1A7ai"],
            "info": {"gases": ["N2O"]},
        },
        "1.A.7.a": {
            "title": "Sugar cane crop residues",
            "comment": "Sugar cane crop residues",
            "alternative_codes": ["1A7a"],
            "info": {"gases": ["N2O"]},
            "children": [["1.A.7.a.ii", "1.A.7.a.i"]],
        },
        "1.A.7.b": {
            "title": "Sugar cane burning crop residues",
            "comment": "Sugar cane burning crop residues",
            "alternative_codes": ["1A7b"],
            "info": {"gases": ["CH4", "N2O"]},
        },
        "1.A.8": {
            "title": "Beans, dry",
            "comment": "Beans, dry",
            "alternative_codes": ["1A8"],
            "info": {"gases": "N2O"},
            "children": [["1.A.8.a"]],
        },
        "1.A.8.a.i": {
            "title": "Beans, dry crop residues direct emissions",
            "comment": "Beans, dry crop residues direct emissions",
            "alternative_codes": ["1A8a"],
            "info": {"gases": ["N2O"]},
        },
        "1.A.8.a.ii": {
            "title": "Beans, dry crop residues indirect emissions",
            "comment": "Beans, dry crop residues indirect emissions",
            "alternative_codes": ["1A8ai"],
            "info": {"gases": ["N2O"]},
        },
        "1.A.8.a": {
            "title": "Beans, dry crop residues",
            "comment": "Beans, dry crop residues",
            "alternative_codes": ["1A8a"],
            "info": {"gases": ["N2O"]},
            "children": [["1.A.8.a.ii", "1.A.8.a.i"]],
        },
        "1.A.9": {
            "title": "Oats",
            "comment": "Oats",
            "alternative_codes": ["1A9"],
            "info": {"gases": "N2O"},
            "children": [["1.A.9.a"]],
        },
        "1.A.9.a.i": {
            "title": "Oats crop residues direct emissions",
            "comment": "Oats crop residues direct emissions",
            "alternative_codes": ["1A9a"],
            "info": {"gases": ["N2O"]},
        },
        "1.A.9.a.ii": {
            "title": "Oats crop residues indirect emissions",
            "comment": "Oats crop residues indirect emissions",
            "alternative_codes": ["1A9ai"],
            "info": {"gases": ["N2O"]},
        },
        "1.A.9.a": {
            "title": "Oats crop residues",
            "comment": "Oats crop residues",
            "alternative_codes": ["1A9a"],
            "info": {"gases": ["N2O"]},
            "children": [["1.A.9.a.ii", "1.A.9.a.i"]],
        },
        "1.A.10": {
            "title": "Rye",
            "comment": "Rye",
            "alternative_codes": ["1A10"],
            "info": {"gases": "N2O"},
            "children": [["1.A.10.a"]],
        },
        "1.A.10.a.i": {
            "title": "Rye crop residues direct emissions",
            "comment": "Rye crop residues direct emissions",
            "alternative_codes": ["1A10a"],
            "info": {"gases": ["N2O"]},
        },
        "1.A.10.a.ii": {
            "title": "Rye crop residues indirect emissions",
            "comment": "Rye crop residues indirect emissions",
            "alternative_codes": ["1A10ai"],
            "info": {"gases": ["N2O"]},
        },
        "1.A.10.a": {
            "title": "Rye crop residues",
            "comment": "Rye crop residues",
            "alternative_codes": ["1A10a"],
            "info": {"gases": ["N2O"]},
            "children": [["1.A.10.a.ii", "1.A.10.a.i"]],
        },
        "1.A.11": {
            "title": "Sorghum",
            "comment": "Sorghum",
            "alternative_codes": ["1A11"],
            "info": {"gases": "N2O"},
            "children": [["1.A.11.a"]],
        },
        "1.A.11.a.i": {
            "title": "Sorghum crop residues direct emissions",
            "comment": "Sorghum crop residues direct emissions",
            "alternative_codes": ["1A11a"],
            "info": {"gases": ["N2O"]},
        },
        "1.A.11.a.ii": {
            "title": "Sorghum crop residues indirect emissions",
            "comment": "Sorghum crop residues indirect emissions",
            "alternative_codes": ["1A11ai"],
            "info": {"gases": ["N2O"]},
        },
        "1.A.11.a": {
            "title": "Sorghum crop residues",
            "comment": "Sorghum crop residues",
            "alternative_codes": ["1A11a"],
            "info": {"gases": ["N2O"]},
            "children": [["1.A.11.a.ii", "1.A.11.a.i"]],
        },
        "1.A.12": {
            "title": "Soya beans",
            "comment": "Soya beans",
            "alternative_codes": ["1A12"],
            "info": {"gases": "N2O"},
            "children": [["1.A.12.a"]],
        },
        "1.A.12.a.i": {
            "title": "Soya beans crop residues direct emissions",
            "comment": "Soya beans crop residues direct emissions",
            "alternative_codes": ["1A12a"],
            "info": {"gases": ["N2O"]},
        },
        "1.A.12.a.ii": {
            "title": "Soya beans crop residues indirect emissions",
            "comment": "Soya beans crop residues indirect emissions",
            "alternative_codes": ["1A12ai"],
            "info": {"gases": ["N2O"]},
        },
        "1.A.12.a": {
            "title": "Soya beans crop residues",
            "comment": "Soya beans crop residues",
            "alternative_codes": ["1A12a"],
            "info": {"gases": ["N2O"]},
            "children": [["1.A.12.a.ii", "1.A.12.a.i"]],
        },
        "1.B": {
            "title": "Synthetic fertilisers",
            "comment": "Synthetic fertilisers",
            "alternative_codes": ["1B"],
            "info": {"gases": ["N2O"]},
            "children": [["1.B.1", "1.B.2"]],
        },
        "1.B.1": {
            "title": "Direct emissions",
            "comment": "Direct emissions",
            "alternative_codes": ["1B1"],
            "info": {"gases": ["N2O"]},
        },
        "1.B.2": {
            "title": "Indirect emissions",
            "comment": "Indirect emissions",
            "alternative_codes": ["1B2"],
            "info": {"gases": ["N2O"]},
            "children": [["1.B.2.a", "1.B.2.b"]],
        },
        "1.B.2.a": {
            "title": "Indirect emissions that volatilise",
            "comment": "Indirect emissions that volatilise",
            "alternative_codes": ["1B2a"],
            "info": {"gases": ["N2O"]},
        },
        "1.B.2.b": {
            "title": "Indirect emissions that leach",
            "comment": "Indirect emissions that leach",
            "alternative_codes": ["1B2b"],
            "info": {"gases": ["N2O"]},
        },
        "2.A": {
            "title": "Natural gas",
            "comment": "Natural gas",
            "alternative_codes": "2A",
            "info": {"gases": ["CH4", "N2O", "CO2"]},
        },
        "2.B": {
            "title": "Electricity",
            "comment": "Electricity",
            "alternative_codes": "2B",
            "info": {"gases": ["CH4", "N2O", "CO2"]},
        },
        "2.C": {
            "title": "Coal",
            "comment": "Coal",
            "alternative_codes": "2C",
            "info": {"gases": ["CH4", "N2O", "CO2"]},
        },
        "2.D": {
            "title": "Heat",
            "comment": "Heat",
            "alternative_codes": "2D",
            "info": {"gases": ["CH4", "N2O", "CO2"]},
        },
        "2.E": {
            "title": "Petroleum",
            "comment": "Petroleum",
            "alternative_codes": "2E",
            "info": {"gases": ["CH4", "N2O", "CO2"]},
        },
        "3.A": {
            "title": "Asses",
            "comment": "Asses",
            "alternative_codes": "3A",
            "info": {"gases": ["CH4", "N2O"]},
        },
        "3.B": {
            "title": "Camels",
            "comment": "Camels",
            "alternative_codes": "3B",
            "info": {"gases": ["CH4", "N2O"]},
        },
        "3.C": {
            "title": "Cattle, dairy",
            "comment": "Cattle, dairy",
            "alternative_codes": "3C",
            "info": {"gases": ["CH4", "N2O"]},
        },
        "3.D": {
            "title": "Cattle, non-dairy",
            "comment": "Cattle, non-dairy",
            "alternative_codes": "3D",
            "info": {"gases": ["CH4", "N2O"]},
        },
        "3.E": {
            "title": "Chickens, broilers",
            "comment": "Chickens, broilers",
            "alternative_codes": "3E",
            "info": {"gases": ["N2O"]},
        },
        "3.F": {
            "title": "Chickens, layers",
            "comment": "Chickens, layers",
            "alternative_codes": "3F",
            "info": {"gases": ["N2O"]},
        },
        "3.G": {
            "title": "Goats",
            "comment": "Goats",
            "alternative_codes": "3G",
            "info": {"gases": ["CH4", "N2O"]},
        },
        "3.H": {
            "title": "Horses",
            "comment": "Horses",
            "alternative_codes": "3H",
            "info": {"gases": ["CH4", "N2O"]},
        },
        "3.I": {
            "title": "Mules and hinnies",
            "comment": "Mules and hinnies",
            "alternative_codes": "3I",
            "info": {"gases": ["CH4", "N2O"]},
        },
        "3.J": {
            "title": "Sheep",
            "comment": "Sheep",
            "alternative_codes": "3J",
            "info": {"gases": ["CH4", "N2O"]},
        },
        "3.K": {
            "title": "Llamas",
            "comment": "Llamas",
            "alternative_codes": "3K",
            "info": {"gases": ["CH4", "N2O"]},
        },
        "3.L": {
            "title": "Chickens",
            "comment": "Chickens",
            "alternative_codes": "3L",
            "info": {"gases": ["N2O"]},
        },
        "3.M": {
            "title": "Poultry Birds",
            "comment": "Poultry Birds",
            "alternative_codes": "3M",
            "info": {"gases": ["N2O"]},
        },
        "3.N": {
            "title": "Buffalo",
            "comment": "Buffalo",
            "alternative_codes": "3N",
            "info": {"gases": ["CH4", "N2O"]},
        },
        "3.O": {
            "title": "Ducks",
            "comment": "Ducks",
            "alternative_codes": "3O",
            "info": {"gases": ["N2O"]},
        },
        "3.P": {
            "title": "Swine, breeding",
            "comment": "Swine, breeding",
            "alternative_codes": "3P",
            "info": {"gases": ["CH4", "N2O"]},
        },
        "3.Q": {
            "title": "Swine, market",
            "comment": "Swine, market",
            "alternative_codes": "3Q",
            "info": {"gases": ["CH4", "N2O"]},
        },
        "3.R": {
            "title": "Turkeys",
            "comment": "Turkeys",
            "alternative_codes": "3R",
            "info": {"gases": ["N2O"]},
        },
    },
}
